@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from os import remove
+
 import numpy as np
 
 import csdmpy as cp
@@ -10,8 +12,7 @@ def setup():
     dimension2 = cp.as_dimension(np.arange(20))
     data = cp.as_dependent_variable(np.random.rand(20, 10))
 
-    csdm.add_dimension(dimension1)
-    csdm.add_dimension(dimension2)
+    csdm.dimensions += [dimension1, dimension2]
     csdm.add_dependent_variable(data)
 
     return csdm
@@ -29,7 +30,6 @@ def test_application():
 
     csdm1.dependent_variables[0].encoding = "base64"
     csdm1.save("csdm1.csdf")
-
     csdm1_test = cp.load("csdm1.csdf", application=True)
-
     assert csdm1_test == csdm1
+    remove("csdm1.csdf")
